"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DiceBear = void 0;
const hash = require("hash.js");
/**
 * Simple wrapper around the DiceBear API.
 * @see https://avatars.dicebear.com/docs/getting-started
 */
class DiceBear {
    /**
     * Generates a random seed used to generate the avatar.
     */
    static randomSeed() {
        return hash.sha256().update(Math.random().toString(36)).digest('hex');
    }
    /**
     * Generates an avatar URL.
     * @param avatarStyleName {DiceBearAvatarStyleName} The avatar style name.
     * @param seed {string} The seed used to generate the avatar.
     */
    static getAvatarUrl(avatarStyleName, seed) {
        if (!seed) {
            seed = this.randomSeed();
        }
        return `https://avatars.dicebear.com/api/${avatarStyleName}/${seed}.svg?backgroundColor=%23333333&textureChance=0&margin=10`;
    }
}
exports.DiceBear = DiceBear;
